---
name: Bug report
about: You found an unexpected behaviour? Use this template.

---

<!--
  Use the template below when reporting bugs.

  Please, make sure that you're running the latest Ox-Hugo (from Melpa
  or git head).
-->

## Actual Behavior

## Expected Behavior

## How to Reproduce the Issue

### Example Org File

### Generated Markdown File or Error

## Ox-Hugo Debug Information

<!--

  (Step 1) Run `M-x org-hugo-debug-info`.

     *That will copy the debug info in Markdown format to the kill ring.*
     So do *not* manually do any other kill (copy/cut) operation after that!

  See step 2 below.
-->

<details>
  <summary>Debug Info</summary>

  <!--
      (Step 2) Paste the Markdown contents (copied to kill-ring in
               Step 1 above)  after `</summary>` and before
               `</details>` below.
  -->

</details>
